 % simulate from discrete distribution

probs = [0.25 0.25 0.5]; % pmf

x = disrnd(1000, probs);

histogram(x, 20, 'normalization', 'probability')

% change pmf

probs = [0.1 0.2 0.3 0.4];

x = disrnd(1000, probs);

histogram(x, 20, 'normalization', 'probability')

% simulate Poisson distribution

ss = 2000;
x = mypoisrnd(ss, 0.5);
histogram(x, 20, 'normalization', 'probability')

% calculate empirical pmf
empdf = zeros(max(x) + 1, 1);

for i = 0:max(x)
    empdf(i+1) = length(x(x == i)) / ss;
end

% calculate true pmf and compare results
trpdf = poisspdf(0:max(x),0.5);

% simulate exponential distribution
ss = 50000;
lambda = 3;
x = myexprnd(ss, lambda);
histogram(x, 20, 'normalization', 'pdf')

% calculate true pdf
xvals = 0:0.01:max(x);
% user defined anonymous function
myexppdf = @(x) lambda * exp(-lambda * x);
yvals = myexppdf(xvals);
% matlab function
% yvals = exppdf(xvals, 1/lambda); 

% compare results
figure
hold on
histogram(x, 50, 'facecolor', 'red', 'normalization', 'pdf')
plot(xvals, yvals, 'color', 'blue', 'linewidth', 2)
legend('empirical', 'true')
title('lambda = 3')
xlabel('x')
ylabel('f(x) - Exponential(lambda)')
hold off

% simulate Gamma distribution
ss = 50000;
shape = 3;
rate = 0.5;
x = mygamrnd(ss, shape, rate);
histogram(x, 20, 'normalization', 'pdf')

% calculate true pdf
xvals = 0:0.01:max(x);
yvals = gampdf(xvals, shape, 1/rate);

% compare results
figure
hold on
histogram(x, 50, 'facecolor', 'red', 'normalization', 'pdf')
plot(xvals, yvals, 'color', 'blue', 'linewidth', 2)
legend('empirical', 'true')
title('shape = 3, rate = 0.5')
xlabel('x')
ylabel('f(x) - Gamma(shape, rate)')
hold off


figure
subplot(2,2,1)
lambda = 0.5;
x = myexprnd(ss, lambda);
xvals = 0:0.01:max(x);
myexppdf = @(x) lambda * exp(-lambda * x);
yvals = myexppdf(xvals);
hold on
histogram(x, 50, 'facecolor', 'red', 'normalization', 'pdf')
plot(xvals, yvals, 'color', 'blue', 'linewidth', 2)
legend('empirical', 'true')
title('lambda = 0.5')
hold off
subplot(2,2,2)
lambda = 5;
x = myexprnd(ss, lambda);
xvals = 0:0.01:max(x);
myexppdf = @(x) lambda * exp(-lambda * x);
yvals = myexppdf(xvals);
hold on
histogram(x, 50, 'facecolor', 'red', 'normalization', 'pdf')
plot(xvals, yvals, 'color', 'blue', 'linewidth', 2)
legend('empirical', 'true')
title('lambda = 5')
hold off
subplot(2,2,3)
lambda = 10;
x = myexprnd(ss, lambda);
xvals = 0:0.01:max(x);
myexppdf = @(x) lambda * exp(-lambda * x);
yvals = myexppdf(xvals);
hold on
histogram(x, 50, 'facecolor', 'red', 'normalization', 'pdf')
plot(xvals, yvals, 'color', 'blue', 'linewidth', 2)
legend('empirical', 'true')
title('lambda = 10')
hold off
subplot(2,2,4)
lambda = 50;
x = myexprnd(ss, lambda);
xvals = 0:0.01:max(x);
myexppdf = @(x) lambda * exp(-lambda * x);
yvals = myexppdf(xvals);
hold on
histogram(x, 50, 'facecolor', 'red', 'normalization', 'pdf')
plot(xvals, yvals, 'color', 'blue', 'linewidth', 2)
legend('empirical', 'true')
title('lambda = 50')
hold off

